package  ORG.netlib.math.complex;



import java.util.Date;

import ORG.netlib.math.complex.Complex;


/*
  Last change:  ALM  22 Jun 97    4:30 am
*/


class ComplexBenchmark {

    static final String MODULE       =  ComplexBenchmark.class.getName();
    static final String VERSION      =  "1.03 final Sun 22-Jun-97 alm";
    static final char   MARK_CHAR    =  '-';
    static       int    ITERATIONS   =  1000000;



    public static void
    main (String[] args) {
        Date start, finish;
        double dummy;
        boolean bool;

        if (args.length > 0) {
            try {
                ITERATIONS =  Integer.valueOf(args[0]).intValue();

                if (ITERATIONS < 0) {
                    throw new NumberFormatException();
                }//endif
            } catch (NumberFormatException e) {
                System.out.println();
                System.out.print("usage:  ");
                System.out.println("java ComplexBenchmark  [loop iterations]");
                System.out.println();

                System.exit(1);
            }//endtry
        }//endif

        System.out.println();
        System.out.println("    This tests on your system, the execution speed of the Complex");
        System.out.println("    functions by repeatedly calling each function " + ITERATIONS + " times.");
        System.out.println();
        System.out.println("                      Alexander Anderson <sandy@almide.demon.co.uk>");
        System.out.println();

        Complex z;
        Complex c =  new Complex(0.1234, 0.5678);


        System.getProperties().list(System.out);
        System.out.println();

        System.out.println("Module : " + MODULE );
        System.out.println("Version: " + VERSION);
        System.out.println("Testing class Complex Version: " + Complex.VERSION);
        System.out.println();
        System.out.println("Benchmark " + ITERATIONS + " started! ...");
        System.out.println();
        System.out.println("(Please be patient.  Each \"" + MARK_CHAR + "\" is one second.)");
        System.out.println();

        System.out.print("Empty Loop   ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            // skip
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("Constructor  ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = new Complex(0.1234, 5.6789);
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("polar()      ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = Complex.polar(0.1234, 5.6789);
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("pow(r, r)    ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            dummy = Math.pow(0.1234, 5.6789);
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("pow(r, C)    ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = Complex.pow(0.1234, c);
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("pow(C, r)    ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = Complex.pow(c, 0.1234);
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("pow(C, C)    ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = Complex.pow(c, c);
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;
/*
        System.out.print("equals()     ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            bool = c.equals(c);
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;
*/
        System.out.print("re()         ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            dummy = c.re();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("norm()       ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            dummy = c.norm();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("abs()        ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            dummy = c.abs();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("arg()        ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            dummy = c.arg();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("neg()        ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.neg();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;
/*
        System.out.print("inv()        ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.inv();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;
*/
        System.out.print("conj()       ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.conj();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("scale()      ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.scale(1.234);
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("add()        ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.add(c);
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("sub()        ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.sub(c);
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("mul()        ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.mul(c);
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("div()        ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.div(c);
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("sqrt()       ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.sqrt();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("exp()        ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.exp();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("log()        ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.log();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;
/*
        System.out.print("log10()      ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.log10();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;
*/
        System.out.print("sin()        ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.sin();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("cos()        ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.cos();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("tan()        ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.tan();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("cosec()      ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.cosec();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("sec()        ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.sec();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("cot()        ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.cot();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("sinh()       ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.sinh();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("cosh()       ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.cosh();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("tanh()       ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.tanh();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("asin()       ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.asin();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("acos()       ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.acos();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("atan()       ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.atan();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("asinh()      ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.asinh();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("acosh()      ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.acosh();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.print("atanh()      ");
        start =  new Date();
        for (int i =  1; i <= ITERATIONS; i++) {
            z = c.atanh();
        };//endfor
        finish =  new Date();
        System.out.println(stars(start, finish));;

        System.out.println("... Benchmark " + ITERATIONS + " finished.");
    };// main(String[])



    static String
    stars (Date start, Date finish) {
        double starSeconds =  Math.round( (finish.getTime() - start.getTime())/1000.0 );
        StringBuffer starString = new StringBuffer();

        for (int i =  1; i <= starSeconds; i++) {
            starString = starString.append(MARK_CHAR);
        };//endfor

        starString.append( " " + (int) starSeconds);

        return starString.toString();
    }// stars(Date,Date)

}// ComplexBenchmark




/*  Correct my address in any reply, or it'll be treated as spam:
--                                                          
//     Alexander Anderson    <DELETE_THIS.sandy@almide.demon.co.uk>
//     Home Fone                               +44 (0) 171-794-4543
//     London, UK                    http://www.almide.demon.co.uk/ 
//     PGP print   C6 8C 55 F2 77 7B 99 9B  14 77 66 F5 B8 74 CF 12
*/
